==> data-platform-telemetry-0.4.6.jar: META-INF/leiningen/com.signal-ai/data-platform-telemetry/README.md <==
# Data Platform Telemetry

Telemetry setup code for Data Platform services.

## Usage

[![Clojars Project](https://img.shields.io/clojars/v/com.signal-ai/data-platform-telemetry.svg)](https://clojars.org/com.signal-ai/data-platform-telemetry)

Include this libary in your `project.clj` (see clojars for the latest version).

```clj
(require '[signal.data-platform-telemetry.metrics :as metrics])

(comment
  ;; view available histogram overrides
  (metrics/get-default-histogram-buckets nil))

;; initialise a metrics registry
;; the returned registry is an iapetos registry - new metrics can be registered using standard iapetos functions
(def metrics-config {;; optional, can disable JVM metrics
                     :jvm? false
                     ;; optional, can disable ring metrics
                     :ring? false

                     ;; optional, can be set to 1 or increased if non-standard
                     ;; can alternatively be overridden via histogram-bucket-overrides
                     :max-batch-size 50

                     ;; overrides for histogram buckets
                     {:histogram-bucket-overrides {:message-process-time [0.1 0.25 0.5 1 2 4 8 16]
                                                    ;; pipeline-document-latency is required when using pipeline-latency as it doesn't have a default
                                                    :pipeline-document-latency [0.1 0.25 0.5 1 2 4 8 16 32 64]}}})


(def registry (-> (metrics/init metrics-config)
                  (metrics/queue-reader metrics-config)
                  (metrics/queue-writer metrics-config)
                  (metrics/pipeline-latency metrics-config)))

;; increment a metric
(metrics/observe-message-total-time registry (System/currentTimeMillis))
```

## Generating histogram buckets
Utility function provided to generate histogram buckets for a given SLO, refer to [generate-pipeline-histogram-buckets](./src/signal/data_platform_telemetry/histogram_buckets.clj#L7) for its usage.

## License

Copyright © 2022 Signal AI

This program and the accompanying materials are made available under the
terms of the Eclipse Public License 2.0 which is available at
http://www.eclipse.org/legal/epl-2.0.

This Source Code may also be made available under the following Secondary
Licenses when the conditions for such availability set forth in the Eclipse
Public License, v. 2.0 are satisfied: GNU General Public License as published by
the Free Software Foundation, either version 2 of the License, or (at your
option) any later version, with the GNU Classpath Exception which is available
at https://www.gnu.org/software/classpath/license.html.

==> data-platform-telemetry-0.4.7.jar: META-INF/leiningen/com.signal-ai/data-platform-telemetry/README.md <==
# Data Platform Telemetry

Telemetry setup code for Data Platform services.

## Usage

[![Clojars Project](https://img.shields.io/clojars/v/com.signal-ai/data-platform-telemetry.svg)](https://clojars.org/com.signal-ai/data-platform-telemetry)

Include this libary in your `project.clj` (see clojars for the latest version).

```clj
(require '[signal.data-platform-telemetry.metrics :as metrics])

(comment
  ;; view available histogram overrides
  (metrics/get-default-histogram-buckets nil))

;; initialise a metrics registry
;; the returned registry is an iapetos registry - new metrics can be registered using standard iapetos functions
(def metrics-config {;; optional, can disable JVM metrics
                     :jvm? false
                     ;; optional, can disable ring metrics
                     :ring? false

                     ;; optional, can be set to 1 or increased if non-standard
                     ;; can alternatively be overridden via histogram-bucket-overrides
                     :max-batch-size 50

                     ;; overrides for histogram buckets
                     {:histogram-bucket-overrides {:message-process-time [0.1 0.25 0.5 1 2 4 8 16]
                                                    ;; pipeline-document-latency is required when using pipeline-latency as it doesn't have a default
                                                    :pipeline-document-latency [0.1 0.25 0.5 1 2 4 8 16 32 64]}}})


(def registry (-> (metrics/init metrics-config)
                  (metrics/queue-reader metrics-config)
                  (metrics/queue-writer metrics-config)
                  (metrics/pipeline-latency metrics-config)))

;; increment a metric
(metrics/observe-message-total-time registry (System/currentTimeMillis))

;; increment a pipeline document latency metric
(defn record-latency [registry received-date-time]
  (metrics/record-pipeline-latency registry {:measured-from "ingestion"} received-date-time))
```

## Generating histogram buckets

A utility function `signal.data-platform-telemetry.metrics/pipeline-document-latency-histogram-buckets` is provided to generate histogram buckets for a given pipeline document latency SLO, refer to [pipeline-document-latency-histogram-buckets](./src/signal/data_platform_telemetry/metrics.clj) for its usage.

## License

Copyright © 2022 Signal AI

This program and the accompanying materials are made available under the
terms of the Eclipse Public License 2.0 which is available at
http://www.eclipse.org/legal/epl-2.0.

This Source Code may also be made available under the following Secondary
Licenses when the conditions for such availability set forth in the Eclipse
Public License, v. 2.0 are satisfied: GNU General Public License as published by
the Free Software Foundation, either version 2 of the License, or (at your
option) any later version, with the GNU Classpath Exception which is available
at https://www.gnu.org/software/classpath/license.html.
